(clean-non-utf8 text)(clean-non-utf8 text replacement)All kinds of junk gets sent in emails so forcibly remove anything that isn't utf8
All kinds of junk gets sent in emails so forcibly remove anything that isn't utf8
(html->text html)Given email message HTML return only the actual text
Given email message HTML return only the actual text
(parse html)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |